@@ -61,6 +61,19 @@ def _queryAndPrint(q,fields=None,systemFields=True,nullFields=False):
     print()
     print(f"Null values printed-> {nullFields}  systemFields printed--> {systemFields}")
 
+def option_readme(args):
+    if '-h' in args:
+        return
+    
+    print(f"""
+    Changes in version 0.49.0
+       Added {utils.CYELLOW}-auto{utils.CEND} to the log parsing. This options activates the debug logs automatically for the -loguser especified. If no -loguser is specified it will do it for the user used to authenticate with the org.  
+            {utils.CGREEN}InCli -logs -u DTI -tail -loguser username:onboarding@nosdti-parceiros.cs109.force.com -deletelogs -auto.{utils.CEND}
+            This command will start listening for new logs for user onboarding@nosdti-parceiros.cs109.force.com in DTI and parsing them in real time. 
+                -auto will activate the debug logs automatically, so the logs are collected without any configuration in Salesforce. 
+                -delete will delete the logs from the server as they are parsed. A local copy for the 
+    """)
+
 def option_q(args):
     if '-h' in args:
         help = f"""
@@ -283,8 +296,9 @@ def option_logs(args):
             {utils.CYELLOW}-error {utils.CEND}--> parses the files saved locally and displays only the ones with errors. {utils.CGREEN}InCli -logs -store -error "{utils.CEND} 
         {utils.CYELLOW}-logs -last X {utils.CEND}--> parses the last X logs. X as number.
         {utils.CYELLOW}-logs -tail {utils.CEND}--> activelly parsers new debug logs as they are created.
-            {utils.CYELLOW}-deletelogs {utils.CEND}--> as log files are processed, they are deleted from the server. The local copy remains. 
-            {utils.CGREEN}-logs -u OrgAlias -where "LogLength>3000"  -tail -deletelogs{utils.CEND} -> parses log files of size > 3000 as they are created. Deletes the retrieved logs. 
+            {utils.CYELLOW}-deletelogs {utils.CEND}--> as log files are processed, they are deleted from the server. The local copy remains. if -loguser is not provided it will default to your User.
+            {utils.CYELLOW}-auto {utils.CEND}--> automaticallyu configures the collection of logs for -loguser. If no -loguser provided defaults to your user. {utils.CBLINK}NEW{utils.CEND}
+            {utils.CYELLOW}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
         {utils.CYELLOW}-logs{utils.CEND} --> lists log records in the org. 
             {utils.CYELLOW}-limit X{utils.CEND}, where X specifies the number of logs to list. Default 50 max 50K
                 {utils.CGREEN}-logs -limit 1000{utils.CEND}, displays the last 1000 log records
@@ -305,6 +319,7 @@ def option_logs(args):
     last = getParam(args,'-last')  
     limit = getParam(args,'-limit')    
     limitInfo = True if '-limitinfo' in args else False   
+    auto = True if '-auto' in args else False   
 
     level = getParam(args,'-level') 
     loguser = getParam(args,'-loguser') 
@@ -338,26 +353,28 @@ def option_logs(args):
         'deleteLogs':deletelogs,
         'parseStore':store,
         'logToStore':True,
-        'onlyErrors':error,
-        'operation':None
+        'print_only_errors':error,
+        'operation':None,
+        'auto':auto
     }
 
     if tail:
-        connectionInit(args)
-        return debugLogs.parseTail(parseContext)
+        connection = connectionInit(args)
+        parseContext['connection'] = connection
+        return debugLogs.do_parse_tail(parseContext)
 
     elif store:
-        return debugLogs.parseStorage(parseContext)
+        return debugLogs.do_parse_storage(parseContext)
 
     elif inputfile != None:
-        return debugLogs.parseFile(parseContext)
+        return debugLogs.do_parse_from_file(parseContext)
 
     elif logId != None:  #check if already downloaded        
         connectionInit(args)
-        return debugLogs.parseLogId(logId,parseContext)
+        return debugLogs.do_parse_logId(logId,parseContext)
     else:
         connectionInit(args)
-        return debugLogs.parseLogs_LastN(parseContext)
+        return debugLogs.do_parse_logs_lastN(parseContext)
 
 def option_h(args):
 
@@ -367,16 +384,15 @@ def option_h(args):
     functions = [func[0] for func in funcs if func[0].startswith('option_')]
 
     for f in functions:
-        if f == 'option_h':
-            continue
+        if f == 'option_h':      continue
         args = '-h'
-        print(eval(f'{f}(args)'))      
-    print()
+        p = eval(f'{f}(args)')
+        if p != None: print(p)
 
 def connectionInit(argsIn):
 
     userName_or_ofgAlias = getParam(argsIn,'-u') 
-    restClient.init(userName_or_ofgAlias)
+    return restClient.init(userName_or_ofgAlias)
 
 def checkVersion():
     try:
@@ -403,10 +419,8 @@ def checkVersion():
 
 def _main(argsIn):
 
-    if "-debug" in argsIn:
-        restClient.setLoggingLevel(level=logging.DEBUG)
-    else:
-        restClient.setLoggingLevel(logging.INFO)
+    if "-debug" in argsIn:    restClient.setLoggingLevel(level=logging.DEBUG)
+    else:  restClient.setLoggingLevel(logging.INFO)
 
     restClient.glog().debug("In debug mode")
     checkVersion()
@@ -415,8 +429,10 @@ def _main(argsIn):
         colorama.just_fix_windows_console()
 
         help = f"""
+        {utils.CYELLOW}-readme{utils.CEND} --> new functionality added and some example. 
+
         {utils.CYELLOW}-u{utils.CEND} --> username or org alias to be used to log into the org. 
-            {utils.CLIGHT_PURPLE}Defaultable u{utils.CEND}: Can be set to a default value --> {utils.CGREEN}InCli -default:set u "xx@adas.com {utils.CEND}"""
+            {utils.CLIGHT_PURPLE}Defaultable u{utils.CEND}: Can be set to a default value --> {utils.CGREEN}InCli -default:set u "xx@adas.com {utils.CEND} """
         print(help)
 
     funcs = getmembers(sys.modules[__name__], isfunction)
@@ -424,21 +440,17 @@ def _main(argsIn):
 
     args = []
     for argv in argsIn:
-        if argv == '|':
-            break
+        if argv == '|':     break
         args.append(argv)
 
     for arg in args:
         ar = arg.split(':')[0][1:]
         ar = f"option_{ar}"
         if ar in functions:
-        #       module = __import__('InCli')
             res = None
             res = eval(f'{ar}(args)')
             if '-h' not in argsIn:
                 return res
-        #      func = getattr(module, ar)
-        #      func(args)
 
     if '-h' in argsIn:
         print()
@@ -459,6 +471,8 @@ def main():
         print("ate ja")
     except Exception as e:
         utils.printException(e)
+        print(traceback.format_exc())
+
         if "-debug" in sys.argv:
             print(traceback.format_exc())
 
