@@ -103,12 +103,22 @@ def queryField(q,field=None,raiseEx=False,X=['Id','Name']):
 
     return fieldList[0]
 
-def queryIdF(objName,extendedF):
+def queryIdF(objName,extendedF,init=None):
+    """Returns the Id for the especified extendedF.
+    - if extendedF is a string, returns the string
+    - if extendedF is a dictionary, return extendedF['Id]
+    - if extendedF is a fieldName:fieldValue, returns the query on object where fieldName=fieldValue
+    """
     if extendedF == None:
         return None
+    if type(extendedF) is dict:
+        extendedF = extendedF['Id']
     ef = utils.extendedField(extendedF)
     if ef['field'] == 'Id':
-        return ef['value']
+        if Sobjects.checkId(ef['value']):
+            return ef['value']
+        else:
+            utils.raiseException("No_Id",f"{extendedF} is not a valid Id")
     return queryField(f" select Id from {objName} where {ef['field']} = '{ef['value']}' ")
 def logQuery(q,filename,raiseEx=False):
     if filename != None:
