@@ -60,12 +60,22 @@ def checklastThreadCallError(caller):
     if 'error' in lc and lc['error'] is not None:
         utils.raiseException(lc['errorCode'],lc['error'],caller)
 
+def getLastCallTimes():
+    t = lastThreadCall()
+    et = t['elapsedTime']
+    delta = t['deltaTime']
+    times = {
+        'elapsed':(et.microseconds + et.seconds * 1000000 )/1000,
+        'delta':(delta.microseconds + delta.seconds * 1000000 )/1000,
+    }
+    return times
 def getLastCallTime():
     return getlastThreadCallTime()
 def getlastThreadCallTime():
     t = lastThreadCall('elapsedTime')
     return (t.microseconds + t.seconds * 1000000 )/1000
 
+
 def getConfigOrgsNames():
     """
     Get all names for the org in the config file."""
@@ -200,6 +210,7 @@ def init(userName_or_orgAlias,connectionName=None):
             if userName_or_orgAlias == None:
                 utils.raiseException('Configuration',"No userName or Org Alias specified. Please specify a user name or org alias.")
             inConf = True    
+            glog().info(f"Using default connection, {userName_or_orgAlias}.")
 
         connectionName = connectionName if connectionName is not None else userName_or_orgAlias
         if _checkAndSetConnectionIfExists(connectionName):
@@ -238,6 +249,7 @@ def init(userName_or_orgAlias,connectionName=None):
         assert(obj['Access Token']!=None)
 
         _initMain(connectionName,obj['Instance Url'],obj['Access Token'],username= obj['Username'])
+        return obj
 
 def initWithToken(name,url,token=None,input=None,output=None,debug=None):
     _initMain(name,url,token,input,output,debug)
@@ -446,14 +458,15 @@ def requestRaw(url,action=None,method = 'get',parameters = {},data={},headers={}
         call['error'] = {'RequestException':f"{err}"}
         call['errorCode'] = f"RequestException"
 
+    call['responseTime'] = datetime.datetime.now()
+    call['deltaTime'] = call['responseTime'] - call['callTime']
+
     if r != None:
         glog().debug(f'Debug: API {method} call: {r.url}  status Code:{r.status_code}' ) 
         
-        call['responseTime'] = datetime.datetime.now()
         call['status_code'] = r.status_code
         call['elapsedTime'] = r.elapsed
         call['elapsedTimeCall'] = r.elapsed
-        call['deltaTime'] = call['responseTime'] - call['callTime']
 
         if r.status_code < 300 :
             if r.text == '':
@@ -470,6 +483,11 @@ def requestRaw(url,action=None,method = 'get',parameters = {},data={},headers={}
         else:
           #  glog().warn('API error when calling %s : %s' % (r.url, r.content))
             call['response'] = call['error']
+    else:
+        call['elapsedTime'] = call['deltaTime']
+        call['elapsedTimeCall'] = call['deltaTime']
+        call['status_code'] = 600
+        call['response'] = 'No Response'
 
     if _currentConnectionName != 'ConnectionLess':
         _updateThreadCall(call)
@@ -559,13 +577,15 @@ def callSave(logFileName,logRequest=False,logReply=True,timeStamp=False,response
     if  timeStamp == False:
         now = ''
     filename = f"{now}{logFileName}"
+    request_filename = None
+    response_filename = None
 
     lc = lastThreadCall()
 
     if logRequest == True:
         fn = f'{filename}_req'
-        filepath = writeFile(fn,lc['data'])
-        lc['requestFilePath'] = filepath
+        request_filename = writeFile(fn,lc['data'])
+        lc['requestFilePath'] = request_filename
 
     if logReply == True:
         if requestProcessing != None:
@@ -573,12 +593,13 @@ def callSave(logFileName,logRequest=False,logReply=True,timeStamp=False,response
         
         fn = f'{filename}_res'
         try:
-            filepath = writeFile(fn,lc['response'])
+            response_filename = writeFile(fn,lc['response'])
         except Exception as e:
-            filepath = writeFile(fn,str(lc['response']))  
-        lc['responseFilePath'] = filepath
+            response_filename = writeFile(fn,str(lc['response']))  
+        lc['responseFilePath'] = response_filename
 
     _updateThreadCall(lc)
+    return request_filename,response_filename
 
 def writeFile(filename,content):
     connection = getCurrentThreadConnection()
@@ -596,3 +617,5 @@ def writeFile(filename,content):
 def initTest():
     init("DEVNOSCAT2",configFolder="../input")     
 
+
+
