@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime,timedelta
 from logging import log
 import logging
 from . import objectUtil
@@ -6,6 +6,7 @@ import inspect,simplejson
 import os,sys
 from posixpath import dirname
 import time
+#import pytz
 import subprocess
 
 
@@ -237,7 +238,7 @@ def deleteNulls(obj,systemFields=True,nulls=True,delAttributes=True):
             res[key] = obj[key]
     return res
 
-def printFormated(records,fieldsString=None,rename=None,exclude=None):
+def printFormated(records,fieldsString=None,rename=None,exclude=None,checkNumber=False,separator=':'):
     """
     - fieldsString: format field%name:field2%name2:field3
         field is the field in the obj. Name is how it will be printed (the short version). 
@@ -248,15 +249,17 @@ def printFormated(records,fieldsString=None,rename=None,exclude=None):
         print('No records to print')
         return
 
+    if type(records) is dict:
+        records = [records]
     print()
     if 'records' in records:
         records = records['records']
 
     if fieldsString == None:
-        fieldsString = ":".join(records[0].keys())
-    fields = fieldsString.split(':')
+        fieldsString = separator.join(records[0].keys())
+    fields = fieldsString.split(separator)
     if exclude != None:
-        fields2 = [field for field in fields if field not in exclude.split(':')]
+        fields2 = [field for field in fields if field not in exclude.split(separator)]
         fields = fields2
 
     _renames = {}
@@ -276,6 +279,7 @@ def printFormated(records,fieldsString=None,rename=None,exclude=None):
         v['size'] = len(v['print_name'])
         _fields[field] = v
 
+    #calculate _fileds size based in value.
     for record in records:
         for key in _fields.keys():
             size = 0
@@ -285,6 +289,7 @@ def printFormated(records,fieldsString=None,rename=None,exclude=None):
                 if size > _fields[key]['size']:
                     _fields[key]['size'] = size
 
+    #print header
     spacing = 2    
     line = ''
     for key in _fields.keys():
@@ -308,9 +313,9 @@ def printFormated(records,fieldsString=None,rename=None,exclude=None):
             val = '' if val is None else str(val) 
             padding = int(field['size']+spacing)
  #           print(f"{padding}  {field['size']}")
-            if _isInt(val):
+            if checkNumber and _isInt(val):
                 line = f"{line}{int(val):>{padding-1}} "
-            elif _isFloat(val):
+            elif checkNumber and _isFloat(val):
                 line = f"{line}{float(val):>{padding-1}.2f} "
             else:
                 line = f"{line}{val:{padding}}"
@@ -475,7 +480,7 @@ def computeTimes(call,name,times,_type=None):
     print (sec)
     return debugTimes
 
-def repeatingSequence(objs,field):
+def get_repeating_sequences(objs,field):
 
     repeatingSequences = []
     lastX = 0
@@ -483,34 +488,33 @@ def repeatingSequence(objs,field):
         a=1
     lenObj = len(objs)
     for x,val in enumerate(objs):
-        if x <= lastX:
-            continue
+        if x <= lastX:    continue
         firstdelta = None
         lastDelta = 0
         positions = []
         if 'output' not in objs[x]:
             oo = objs[x]
         objx = objs[x]['output']
-   #     if objs[x][field]=='OrderItem CancelWF --> false':
-   #         print(x)
+
+        max = 8
+        seq = False
 
         for y in range(x+1,len(objs)):
-         #   if y>(lenObj-x)/2:
-         #       break
+            if seq == False and y-x>=max:
+                break
             if 'output' not in objs[y]:
                 oo = objs[y]
             objy=objs[y]['output']
 
             if field not in objs[y]:
                 _o = objs[y]
-            if objs[y][field] == objs[x][field]:
+            if 'ident' in objs[y] and 'ident' in objs[x] and objs[y]['ident'] == objs[x]['ident'] and objs[y][field] == objs[x][field]:
                 line = objs[y][field]
 
                 if firstdelta == None:
                     firstdelta = y-x
                     lastDelta = firstdelta
-                else:
-                    lastDelta = y - lastX
+                else:   lastDelta = y - lastX
                 
                 seq = True
                 if lastDelta == firstdelta:
@@ -524,22 +528,20 @@ def repeatingSequence(objs,field):
                             seq = False
                             break
                     if seq == True:
-                        if len(positions) == 0:
-                            positions.append(y-firstdelta)
+                        if len(positions) == 0:   positions.append(y-firstdelta)
                         positions.append(y)
-                else:
-                    break
-                if seq == True:
-                    lastX = y 
+                else:  break
+                if seq == True:     lastX = y 
 
-        if len(positions) > 0:
-            repeatingSequences.append(positions)
-    #        print(f"{positions}   {firstdelta}" )
-    #        for p in positions:
-    #            for m in range(0,firstdelta):
-
-     #               print(f"{p+m}  {objs[p+m][field]}")
-     #       print()
+        if len(positions) > 0:  repeatingSequences.append(positions)
 
     return repeatingSequences
-    print(repeatingSequences)
\ No newline at end of file
+    print(repeatingSequences)
+
+def datetime_now_string(format = '%Y-%m-%dT%H:%M:%S%z',addMinutes=0):
+    tz2 = datetime.now().astimezone()
+    if addMinutes != 0:
+        tz2 = tz2 + timedelta(minutes = addMinutes)
+    st = tz2.strftime(format)
+
+    return st
