@@ -5,11 +5,11 @@ import traceback
 
 class Test_Parse(unittest.TestCase):
 
-    def isRep(self,repss,x,parsedLine):
+    def isRep(self,repeatingSequences,x,parsedLine):
       if parsedLine['type'] != 'METHOD':
         return False,None
 
-      for reps in repss:
+      for reps in repeatingSequences:
         delta = reps[1]-reps[0]
         if x>= reps[0] and x <= reps[0] + len(reps) * delta - 1:
           if x>= reps[0] and x <= reps[0] + delta-1:
@@ -30,13 +30,13 @@ class Test_Parse(unittest.TestCase):
         parseContext = {
           'filepath':f'/Users/uormaechea/Documents/Dev/python/VirtualEnvs/prj1/.incli/logs/{logId}.log'
         }
-        parsed = debugLogs.parseFile(parseContext) #.parseLog(filepath=f'/Users/uormaechea/Documents/Dev/python/VirtualEnvs/prj1/.incli/logs/{logId}.log')
+        parsed = debugLogs.do_parse_from_file(parseContext) 
 
-        repss = utils.repeatingSequence(parsed,"output")
+        repeatingSequences = utils.get_repeating_sequences(parsed,"output")
 
         parsedX = []
         for x,parsedLine in enumerate(parsed):
-          isrepe, obj = self.isRep(repss,x,parsedLine)
+          isrepe, obj = self.isRep(repeatingSequences,x,parsedLine)
           if isrepe == True and obj == None:
             continue
           parsedX.append(parsedLine)
@@ -47,10 +47,10 @@ class Test_Parse(unittest.TestCase):
         print(e)
         print(traceback.format_exc())
 
-    def test_parseStorage(self):
+    def test_do_parse_storage(self):
       try:
         restClient.init('ConnectionLess')
-        debugLogs.parseStorage()
+        debugLogs.do_parse_storage()
       except Exception as e:
         print(e)
         traceback.format_exc()
